# coding: utf-8

"""
    Mail-in-a-Box

    Mail-in-a-Box API HTTP specification.  # Introduction This API is documented in [**OpenAPI format**](http://spec.openapis.org/oas/v3.0.3). ([View the full HTTP specification](https://raw.githubusercontent.com/mail-in-a-box/mailinabox/api-spec/api/mailinabox.yml).)  All endpoints are relative to `https://{host}/admin` and are secured with [`Basic Access` authentication](https://en.wikipedia.org/wiki/Basic_access_authentication). If you have multi-factor authentication enabled, authentication with a `user:password` combination will fail unless a valid OTP is supplied via the `x-auth-token` header. Authentication via a `user:user_key` pair is possible without the header being present.   # noqa: E501

    The version of the OpenAPI document: 0.51.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailinabox_api
from mailinabox_api.api.ssl_api import SSLApi  # noqa: E501
from mailinabox_api.rest import ApiException


class TestSSLApi(unittest.TestCase):
    """SSLApi unit test stubs"""

    def setUp(self):
        self.api = mailinabox_api.api.ssl_api.SSLApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_generate_sslcsr(self):
        """Test case for generate_sslcsr

        Generate SSL CSR  # noqa: E501
        """
        pass

    def test_get_ssl_status(self):
        """Test case for get_ssl_status

        Get SSL status  # noqa: E501
        """
        pass

    def test_install_ssl_certificate(self):
        """Test case for install_ssl_certificate

        Install SSL certificate  # noqa: E501
        """
        pass

    def test_provision_ssl_certificates(self):
        """Test case for provision_ssl_certificates

        Provision SSL certificates  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
