from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from mailinabox_api.api.dns_api import DNSApi
from mailinabox_api.api.mfa_api import MFAApi
from mailinabox_api.api.mail_api import MailApi
from mailinabox_api.api.ssl_api import SSLApi
from mailinabox_api.api.system_api import SystemApi
from mailinabox_api.api.user_api import UserApi
from mailinabox_api.api.web_api import WebApi
