# coding: utf-8

"""
    Mail-in-a-Box

    Mail-in-a-Box API HTTP specification.  # Introduction This API is documented in [**OpenAPI format**](http://spec.openapis.org/oas/v3.0.3). ([View the full HTTP specification](https://raw.githubusercontent.com/mail-in-a-box/mailinabox/api-spec/api/mailinabox.yml).)  All endpoints are relative to `https://{host}/admin` and are secured with [`Basic Access` authentication](https://en.wikipedia.org/wiki/Basic_access_authentication). If you have multi-factor authentication enabled, authentication with a `user:password` combination will fail unless a valid OTP is supplied via the `x-auth-token` header. Authentication via a `user:user_key` pair is possible without the header being present.   # noqa: E501

    The version of the OpenAPI document: 0.51.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailinabox_api
from mailinabox_api.api.mfa_api import MFAApi  # noqa: E501
from mailinabox_api.rest import ApiException


class TestMFAApi(unittest.TestCase):
    """MFAApi unit test stubs"""

    def setUp(self):
        self.api = mailinabox_api.api.mfa_api.MFAApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_mfa_status(self):
        """Test case for mfa_status

        Retrieve MFA status for you or another user  # noqa: E501
        """
        pass

    def test_mfa_totp_disable(self):
        """Test case for mfa_totp_disable

        Disable multi-factor authentication for you or another user  # noqa: E501
        """
        pass

    def test_mfa_totp_enable(self):
        """Test case for mfa_totp_enable

        Enable TOTP authentication  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
