# coding: utf-8

"""
    Mail-in-a-Box

    Mail-in-a-Box API HTTP specification.  # Introduction This API is documented in [**OpenAPI format**](http://spec.openapis.org/oas/v3.0.3). ([View the full HTTP specification](https://raw.githubusercontent.com/mail-in-a-box/mailinabox/api-spec/api/mailinabox.yml).)  All endpoints are relative to `https://{host}/admin` and are secured with [`Basic Access` authentication](https://en.wikipedia.org/wiki/Basic_access_authentication). If you have multi-factor authentication enabled, authentication with a `user:password` combination will fail unless a valid OTP is supplied via the `x-auth-token` header. Authentication via a `user:user_key` pair is possible without the header being present.   # noqa: E501

    The version of the OpenAPI document: 0.51.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailinabox_api
from mailinabox_api.api.system_api import SystemApi  # noqa: E501
from mailinabox_api.rest import ApiException


class TestSystemApi(unittest.TestCase):
    """SystemApi unit test stubs"""

    def setUp(self):
        self.api = mailinabox_api.api.system_api.SystemApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_system_backup_config(self):
        """Test case for get_system_backup_config

        Get system backup config  # noqa: E501
        """
        pass

    def test_get_system_backup_status(self):
        """Test case for get_system_backup_status

        Get system backup status  # noqa: E501
        """
        pass

    def test_get_system_privacy_status(self):
        """Test case for get_system_privacy_status

        Get system privacy status  # noqa: E501
        """
        pass

    def test_get_system_reboot_status(self):
        """Test case for get_system_reboot_status

        Get system reboot status  # noqa: E501
        """
        pass

    def test_get_system_status(self):
        """Test case for get_system_status

        Get system status  # noqa: E501
        """
        pass

    def test_get_system_updates(self):
        """Test case for get_system_updates

        Get system updates  # noqa: E501
        """
        pass

    def test_get_system_upstream_version(self):
        """Test case for get_system_upstream_version

        Get system upstream version  # noqa: E501
        """
        pass

    def test_get_system_version(self):
        """Test case for get_system_version

        Get system version  # noqa: E501
        """
        pass

    def test_reboot_system(self):
        """Test case for reboot_system

        Reboot system  # noqa: E501
        """
        pass

    def test_update_system_backup_config(self):
        """Test case for update_system_backup_config

        Update system backup config  # noqa: E501
        """
        pass

    def test_update_system_packages(self):
        """Test case for update_system_packages

        Update system packages  # noqa: E501
        """
        pass

    def test_update_system_privacy(self):
        """Test case for update_system_privacy

        Update system privacy  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
